==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/LinearGraphRangeDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let LinearGraphRangeDescription = /*@__PURE__*/ (() => {
    class LinearGraphRangeDescription extends Description {
        constructor() {
            super();
            this.u = null;
            this.t = null;
            this.v = null;
            this.k = 0;
            this.f = 0;
            this.h = 0;
            this.g = 0;
            this.j = 0;
            this.i = 0;
            this.l = 0;
        }
        get_type() {
            return "LinearGraphRange";
        }
        get type() {
            return this.get_type();
        }
        get name() {
            return this.u;
        }
        set name(a) {
            this.u = a;
            this.e("Name");
        }
        get brush() {
            return this.t;
        }
        set brush(a) {
            this.t = a;
            this.e("Brush");
        }
        get outline() {
            return this.v;
        }
        set outline(a) {
            this.v = a;
            this.e("Outline");
        }
        get startValue() {
            return this.k;
        }
        set startValue(a) {
            this.k = a;
            this.e("StartValue");
        }
        get endValue() {
            return this.f;
        }
        set endValue(a) {
            this.f = a;
            this.e("EndValue");
        }
        get innerStartExtent() {
            return this.h;
        }
        set innerStartExtent(a) {
            this.h = a;
            this.e("InnerStartExtent");
        }
        get innerEndExtent() {
            return this.g;
        }
        set innerEndExtent(a) {
            this.g = a;
            this.e("InnerEndExtent");
        }
        get outerStartExtent() {
            return this.j;
        }
        set outerStartExtent(a) {
            this.j = a;
            this.e("OuterStartExtent");
        }
        get outerEndExtent() {
            return this.i;
        }
        set outerEndExtent(a) {
            this.i = a;
            this.e("OuterEndExtent");
        }
        get strokeThickness() {
            return this.l;
        }
        set strokeThickness(a) {
            this.l = a;
            this.e("StrokeThickness");
        }
    }
    LinearGraphRangeDescription.$t = /*@__PURE__*/ markType(LinearGraphRangeDescription, 'LinearGraphRangeDescription', Description.$);
    return LinearGraphRangeDescription;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/LinearGraphRangeDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let LinearGraphRangeDescription = /*@__PURE__*/ (() => {
    class LinearGraphRangeDescription extends Description {
        get_type() {
            return "LinearGraphRange";
        }
        get type() {
            return this.get_type();
        }
        constructor() {
            super();
            this.w = null;
            this.v = null;
            this.x = null;
            this.m = 0;
            this.h = 0;
            this.j = 0;
            this.i = 0;
            this.l = 0;
            this.k = 0;
            this.n = 0;
        }
        get name() {
            return this.w;
        }
        set name(a) {
            this.w = a;
            this.g("Name");
        }
        get brush() {
            return this.v;
        }
        set brush(a) {
            this.v = a;
            this.g("Brush");
        }
        get outline() {
            return this.x;
        }
        set outline(a) {
            this.x = a;
            this.g("Outline");
        }
        get startValue() {
            return this.m;
        }
        set startValue(a) {
            this.m = a;
            this.g("StartValue");
        }
        get endValue() {
            return this.h;
        }
        set endValue(a) {
            this.h = a;
            this.g("EndValue");
        }
        get innerStartExtent() {
            return this.j;
        }
        set innerStartExtent(a) {
            this.j = a;
            this.g("InnerStartExtent");
        }
        get innerEndExtent() {
            return this.i;
        }
        set innerEndExtent(a) {
            this.i = a;
            this.g("InnerEndExtent");
        }
        get outerStartExtent() {
            return this.l;
        }
        set outerStartExtent(a) {
            this.l = a;
            this.g("OuterStartExtent");
        }
        get outerEndExtent() {
            return this.k;
        }
        set outerEndExtent(a) {
            this.k = a;
            this.g("OuterEndExtent");
        }
        get strokeThickness() {
            return this.n;
        }
        set strokeThickness(a) {
            this.n = a;
            this.g("StrokeThickness");
        }
    }
    LinearGraphRangeDescription.$t = /*@__PURE__*/ markType(LinearGraphRangeDescription, 'LinearGraphRangeDescription', Description.$);
    return LinearGraphRangeDescription;
})();
